@@ -13,28 +13,31 @@ BEGIN{
 	use_ok('WWW::ManageWP::Simple');
 }
 
-sub new {
-	my $class = shift;
-	return bless({}, $class);
-}
-
 ##########
 ## Core ##
 ##########
 
 sub run_all {
 	my $class = shift;
-	$class->base_load();
-	$class->base_methods();
-	$class->remote_load();
-	$class->remote_methods();
+	foreach my $request (qw/get delete post_form/) {
+		mock("HTTP::Tiny::$request", sub {
+			return {
+				success => 1,
+				status  => 200,
+				content => '{"message":"1","status":"0"}',
+			}
+		});
+	}
+	$class->base();
+	$class->remote();
+	$class->simple();
 }
 
 ################
 ## Base Tests ##
 ################
 
-sub base_load {
+sub base {
 	eval{WWW::ManageWP->new()};
 	is(
 		$@,
@@ -51,37 +54,29 @@ sub base_load {
 		apiURL => $testurl,
 	);
 	isa_ok($managewp, 'WWW::ManageWP');
-}
-
-sub base_methods {
-	my ($testkey, $testurl) = qw(
-		foobarbazbarfoobarbazbar123
-		http://localhost/testapi/
-	);
-	my $managewp = WWW::ManageWP->new(
-		apiKEY => $testkey,
-		apiURL => $testurl,
-	);
-	isa_ok($managewp, 'WWW::ManageWP');
+	isa_ok($managewp->remote, 'WWW::ManageWP::Remote');
+	isa_ok($managewp->simple, 'WWW::ManageWP::Simple');
 	is($managewp->apiKEY, $testkey, returned_expected('apiKEY'));
 	is($managewp->apiURL, $testurl, returned_expected('apiURL'));
+	# autoload
+	eval {$managewp->foobar};
+	is($@, "ERROR! [foobar] is not a valid method\n", returned_expected('AUTOLOAD'));
+	undef($@);
+	# private methods
+	eval {$managewp->_prep_args(['foo', 'bar'], {})};
+	is($@, "[foo] is a required parameter\n", returned_expected('_prep_args'));
+	my %hash    = (foo => 1, bar => 1);
+	my $hashref = $managewp->_prep_args([], %hash);
+	is ($hash{foo}, $hashref->{foo}, returned_expected('_prep_args'));
+	is ($hash{bar}, $hashref->{bar}, returned_expected('_prep_args'));
+
 }
 
 ##################
 ## Remote Tests ##
 ##################
 
-sub remote_load {
-	eval{WWW::ManageWP::Remote->new()};
-	is(
-		$@,
-		"[apiKEY] is a required parameter\n",
-		'trying to make a new object without credentials fails',
-	);
-	undef($@);
-}
-
-sub remote_methods {
+sub remote {
 	my ($testkey, $testurl) = qw(
 		foobarbazbarfoobarbazbar123
 		http://localhost/testapi/
@@ -97,27 +92,6 @@ sub remote_methods {
 		"[method] is a required parameter\n",
 		failed_expected('get'),
 	);
-	mock('HTTP::Tiny::get', sub {
-		return {
-			success => 1,
-			status  => 200,
-			content => '{"testinfo":"1","status":"0"}',
-		}
-	});
-	mock('HTTP::Tiny::delete', sub {
-		return {
-			success => 1,
-			status  => 200,
-			content => '{"testinfo":"1","status":"0"}',
-		}
-	});
-	mock('HTTP::Tiny::post_form', sub {
-		return {
-			success => 1,
-			status  => 200,
-			content => '{"testinfo":"1","status":"0"}',
-		}
-	});
 	my $res;
 	$res = $remote->delete(
 		request_params => {
@@ -126,7 +100,7 @@ sub remote_methods {
 		},
 		method => 'users/remove',
 	);
-	ok($res->{testinfo}, returned_expected('delete'));
+	ok($res->{message}, returned_expected('delete'));
 	$res = $remote->get(
 		request_params => {
 			test_param1 => 1,
@@ -134,7 +108,7 @@ sub remote_methods {
 		},
 		method => 'users/list',
 	);
-	ok($res->{testinfo}, returned_expected('get'));
+	ok($res->{message}, returned_expected('get'));
 	$res = $remote->post(
 		request_params => {
 			test_param1 => 1,
@@ -142,7 +116,7 @@ sub remote_methods {
 		},
 		method => 'users/register',
 	);
-	ok($res->{testinfo}, returned_expected('post'));
+	ok($res->{message}, returned_expected('post'));
 	isa_ok($remote->http, 'HTTP::Tiny');
 	isa_ok($remote->json, 'JSON');
 	# private method tests
@@ -170,6 +144,38 @@ sub remote_methods {
 	);
 }
 
+##################
+## Simple Tests ##
+##################
+
+sub simple {
+	my ($testkey, $testurl) = qw(
+		foobarbazbarfoobarbazbar123
+		http://localhost/testapi/
+	);
+	my $simple = WWW::ManageWP::Simple->new(
+		apiKEY => $testkey,
+		apiURL => $testurl,
+	);
+	isa_ok($simple, 'WWW::ManageWP::Simple');
+	my $users = $simple->list_users();
+	ok($users->{message}, returned_expected('list_users'));
+	my $register_response = $simple->register_user(user_email => 'test@example.com');
+	ok($register_response->{message}, returned_expected('register_user'));
+	my $remove_response = $simple->remove_user(user_email => 'test@example.com');
+	ok($remove_response->{message}, returned_expected('remove_user'));
+	my $autologin_response = $simple->autologin_user(user_email => 'test@example.com');
+	ok($autologin_response->{message}, returned_expected('autologin_user'));
+	my $changeplan_response = $simple->change_plan(
+		user_email => 'test@example.com',
+		plan_id    => 'testplan1',
+	);
+	ok($changeplan_response->{message}, returned_expected('change_plan'));
+	# private methods
+	eval {$simple->_email_or_die('not an email address')};
+	is($@, "ERROR! email address [not an email address}] is not valid\n", returned_expected('_email_or_die'));
+}
+
 ##########
 ## Help ##
 ##########
